@@ -3,11 +3,11 @@
 #' Uses `R CMD INSTALL` to install the package. Will also try to install
 #' dependencies of the package from CRAN, if they're not already installed.
 #'
-#' By default, installation takes place using the current package directory.
-#' If you have compiled code, this means that artefacts of compilation will be
-#' created in the `src/` directory. If you want to avoid this, you can
-#' use `build = TRUE` to first build a package bundle and then install
-#' it from a temporary directory. This is slower, but keeps the source
+#' If `quick = TRUE`, installation takes place using the current package
+#' directory. If you have compiled code, this means that artefacts of
+#' compilation will be created in the `src/` directory. If you want to avoid
+#' this, you can use `build = TRUE` to first build a package bundle and then
+#' install it from a temporary directory. This is slower, but keeps the source
 #' directory pristine.
 #'
 #' If the package is loaded, it will be reloaded after installation. This is
@@ -32,7 +32,7 @@
 #' @param build_vignettes if `TRUE`, will build vignettes. Normally it is
 #'   `build` that's responsible for creating vignettes; this argument makes
 #'   sure vignettes are built even if a build never happens (i.e. because
-#'   `local = TRUE`).
+#'   `build = FALSE`).
 #' @param keep_source If `TRUE` will keep the srcrefs from an installed
 #'   package. This is useful for debugging (especially inside of RStudio).
 #'   It defaults to the option `"keep.source.pkgs"`.
@@ -56,11 +56,13 @@ install <-
     # Forcing all of the promises for the current namespace now will avoid lazy-load
     # errors when the new package is installed overtop the old one.
     # https://stat.ethz.ch/pipermail/r-devel/2015-December/072150.html
-    if (is_loaded(pkg)) {
+    if (reload && is_loaded(pkg)) {
       eapply(pkgload::ns_env(pkg$package), force, all.names = TRUE)
     }
 
     if (isTRUE(build_vignettes)) {
+      # we likely need all Suggested dependencies if building vignettes
+      dependencies <- TRUE
       build_opts <- c("--no-resave-data", "--no-manual")
     } else {
       build_opts <- c("--no-resave-data", "--no-manual", "--no-build-vignettes")
@@ -75,7 +77,7 @@ install <-
     }
     opts <- c(opts, args)
 
-    check_dots_used()
+    check_dots_used(action = getOption("devtools.ellipsis_action", rlang::warn))
 
     remotes::install_deps(pkg$path,
       build = build, build_opts = build_opts,
@@ -93,7 +95,7 @@ install <-
     was_loaded <- is_loaded(pkg)
     was_attached <- is_attached(pkg)
 
-    if (was_loaded) {
+    if (reload && was_loaded) {
       pkgload::unload(pkg$package)
     }
 
@@ -131,9 +133,10 @@ install_deps <- function(pkg = ".",
                          ...) {
   pkg <- as.package(pkg)
 
-  check_dots_used()
+  check_dots_used(action = getOption("devtools.ellipsis_action", rlang::warn))
 
-  remotes::install_deps(pkg$path,
+  remotes::install_deps(
+    pkg$path,
     dependencies = dependencies,
     repos = repos,
     type = type,
@@ -160,9 +163,17 @@ install_dev_deps <- function(pkg = ".",
 
   pkg <- as.package(pkg)
 
-  check_dots_used()
+  check_dots_used(action = getOption("devtools.ellipsis_action", rlang::warn))
 
-  remotes::install_deps(pkg$path, ...,
-    dependencies = TRUE, upgrade = upgrade
+  remotes::install_deps(
+    pkg$path,
+    dependencies = dependencies,
+    repos = repos,
+    type = type,
+    upgrade = upgrade,
+    quiet = quiet,
+    build = build,
+    build_opts = build_opts,
+    ...
   )
 }
